%Iceland.m: Simulates Iceland and produces simulation data with hbar
%heterogeneity for comparison with Bianchi Et Al (2001)

gens=60;
step=1/gens;
time=0:step:1;
press=.0001;
presh=.01;

time=0:step:1; 
gamma=2; %preference parameter in the utility function 
e0=1;e1=0; %intercept and slope of age-productivity profile.

%calibration of mu and hbar - straight from Rogerson-Wallenius code
h0t=.45; %target value for hmmax, so that 30% of discretionary time per week is worked
lamt=.2325;%target value for share of lifetime working
taut=.7427; %initial average tax rate = 74.27%
taun=.16685; %average tax rate after = 16.685%
taun2=.7427; % Returns to 74.27% after
hbar=((e0*(1-lamt)+e1*lamt)/e0)^(1/gamma)*h0t*gamma/(1+gamma); %formula to
%calibrate hbar
mua=e0/h0t^gamma/(e0*h0t/(1/gamma+2).*(1-(1-lamt).^(1/gamma+2))-e0*hbar/2*(1-(1-lamt).^2)); %not sure what this is
mu=(1-taut)*e0/h0t^gamma/...
    (h0t/e0^(1/gamma)/(1/gamma+2)/(e1-e0).*((e0*(1-lamt)+e1*lamt).^(1/gamma+2)-e0^(1/gamma+2))-...
    hbar/2/(e1-e0).*((e0*(1-lamt)+e1*lamt).^2-e0^2)); %Really ugly expression for alpha (they call mu here, but alpha in paper)

%run simulation
[hoursprof lfpprof nhoursprof nlfpprof]=CanadaSimOLG_iterative(hbar,mu,e0,e1,gamma,taut,taun,taun2,gens/20,gens,press,presh);

time2=[-60:step*60:60];
nhoursprof2=[hoursprof(2:gens+1) nhoursprof];
hoursprof2=[hoursprof(2:gens+1) hoursprof];
nlfpprof2=[lfpprof(2:gens+1) nlfpprof];
lfpprof2=[lfpprof(2:gens+1) lfpprof];
outmat=[time2' lfpprof2' nlfpprof2'];
csvwrite('canada-point5-iterative.csv', outmat);