function [hoursprof assetprof] = RWSim_iterative(hbar,mu,e0,e1,gamma,tau,gens,svec,hvec,stp1mat,hmat,ghmat,diffmat,evec,vht,u)
%RWSim_iterative2: Simulate the standard RW model using iteerative methods
%and compute asset profile for given hbar mu gamma and tau.
%Use gens generations
%version 1: to save computation time pass in matrices

%time and generations
step=1/(gens-1);
time=0:step:1;
ss=size(svec); ss=ss(1);
sh=size(hvec); sh=sh(1);

%hours policy, asset policy, and value function matrices
hoursmat=zeros(ss,gens);
assetsmat=zeros(ss,gens);
choicemat=zeros(ss,gens);
valmat=zeros(ss,gens);
consmat=zeros(ss,gens);

%Get transfer policy from RWSim
rwhours=RWSim(hbar,mu,e0,e1,gamma,tau,gens-1);
trans=tau*step*evec'*max(rwhours-hbar,0);
trans=diag(trans);

%Terminal period: just choose hours
vmat=step*u(diffmat+evec(gens)*ghmat+repmat(trans(gens),ss*sh,ss))-vht; %value function for each choice of assets and hours
vmat(stp1mat~=0)=-inf; %force to choose zero assets in terminal period. Requies step to be such that zero assets is an option
[vals indices]=max(vmat); %maximize across colums to get value functions and indices of optima
hoursmat(:,gens)=hmat(indices,1);
valmat(:,gens)=vals';

%backwards Bellman iteration
for(t=gens-1:-1:1)
    vmat=step*u(diffmat+evec(t)*ghmat+repmat(trans(t),ss*sh,ss))-vht+repmat(valmat(:,t+1),sh,ss); %value function for each choice of assets and hours
    [vals indices]=max(vmat); %maximize across colums to get value functions and indices of optima
    hoursmat(:,t)=hmat(indices,1);
    assetsmat(:,t)=stp1mat(indices,1);
    valmat(:,t)=vals;
    choicemat(:,t)=mod(indices-1,ss)+1;
end

%trace through assetmat to get optimal choices, then use this to build
%hours and asset profiles
assetindexprof=zeros(gens,1);
assetprof=zeros(gens,1);
hoursprof=zeros(gens,1);
assetindexprof(1)=find(svec==0);
hoursprof(1)=hoursmat(assetindexprof(1),1);
for(t=2:gens)
    assetindexprof(t)=choicemat(assetindexprof(t-1),t-1);
    assetprof(t)=svec(assetindexprof(t));
    hoursprof(t)=hoursmat(assetindexprof(t),t);
end
end
